﻿using Okra.Navigation;
using Stimulsoft.Report;
using System;
using System.ComponentModel;
using System.Composition;
using System.Linq;
using Windows.Storage;

namespace OkraVsStimulsoftDemo.ViewModel
{
    [ViewModelExport (SpecialPageNames.Home)]
    class MainViewModel : INotifyPropertyChanged
    {
        private string FILE_NAME = "Assets\\TestReport.mrt";

        [ImportingConstructor]
        public MainViewModel()
        {
            LoadReport(FILE_NAME);
        }

        #region Properties

        public const string ReportPropertyName = "Report";
        private StiReport _report;
        public StiReport Report
        {
            get { return _report; }
            set
            {
                if (_report == value)
                { return; }

                _report = value;
                RaisePropertyChanged(ReportPropertyName);
            }
        }

        #endregion

        #region Methods

        private async void LoadReport(string reportName)
        {
            StorageFile storage = await Windows.ApplicationModel.Package.Current.InstalledLocation.GetFileAsync(reportName);
            StiReport report = new StiReport();
            await report.LoadAsync(storage);
            await report.RenderAsync();

            this.Report = report;
        }

        #endregion

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;

        protected void RaisePropertyChanged(String propertyName)
        {
            var lHandler = PropertyChanged;
            if (lHandler != null)
            {
                lHandler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion
    }
}
